igeldb.lock


acquire-all!clj

(acquire-all! dirs)

Exclusively lock every canonical directory in dirs.

A persistent .igeldb.lock file is used in each directory. The file itself is deliberately not deleted on release: deleting it after another process has acquired the released inode could allow a third process to lock a new inode.

Exclusively lock every canonical directory in `dirs`.

A persistent `.igeldb.lock` file is used in each directory. The file itself is
deliberately not deleted on release: deleting it after another process has
acquired the released inode could allow a third process to lock a new inode.
sourceraw docstring

release-all!clj

(release-all! locks)

Release directory locks in reverse acquisition order. Idempotent.

Release directory locks in reverse acquisition order. Idempotent.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries