igeldb.memtable


create-memtableclj

(create-memtable wal-chan registry)

Create a new (empty) memtable sharing the global tx registry.

Create a new (empty) memtable sharing the global tx `registry`.
sourceraw docstring

entry-setclj

(entry-set memtable)

The memtable's [ikey data] entries in InternalKey order (an immutable snapshot).

The memtable's [ikey data] entries in InternalKey order (an immutable snapshot).
sourceraw docstring

init-memtableclj

(init-memtable wal-chan registry config)

Initialize the memtable, restoring data from the WAL. Returns [wal-id memtable]. Seeds the shared registry's commit-order counter to the max replayed seq so new writes get higher seqs (Step 7 also folds in the manifest max-seq). The size is the actual byte size of the replayed entries.

Initialize the memtable, restoring data from the WAL. Returns `[wal-id
memtable]`. Seeds the shared `registry`'s commit-order counter to the max
replayed seq so new writes get higher seqs (Step 7 also folds in the manifest
max-seq). The `size` is the actual byte size of the replayed entries.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries