Clojure only.

igeldb.scan


merge-resultsclj

(merge-results higher-precedence lower-precedence)

Merge two ordered scan result sequences. Values from higher-precedence replace values with the same user key in lower-precedence.

Merge two ordered scan result sequences. Values from `higher-precedence`
replace values with the same user key in `lower-precedence`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries