igeldb.store


IStoreMutatecljprotocol

Interface for mutations to the data store

Interface for mutations to the data store

delete!clj

(delete! this k)

write!clj

(write! this k v)

write-batch!clj

(write-batch! this entries)

write-data!clj

(write-data! this k data)
sourceraw docstring

IStoreReadcljprotocol

Interface for reading from the data store, at a given snapshot-seq (the newest version of each user_key with seq <= snapshot-seq). Non-tx reads pass Long/MAX_VALUE (latest).

Interface for reading from the data store, at a given `snapshot-seq` (the
newest version of each user_key with seq <= snapshot-seq). Non-tx reads pass
`Long/MAX_VALUE` (latest).

latest-seqclj

(latest-seq this k)

scanclj

(scan this from-key to-key snapshot-seq)

selectclj

(select this k snapshot-seq)
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries