(acquire-all! dirs)Exclusively lock every canonical directory in dirs.
A persistent .igeldb.lock file is used in each directory. The file itself is
deliberately not deleted on release: deleting it after another process has
acquired the released inode could allow a third process to lock a new inode.
Exclusively lock every canonical directory in `dirs`. A persistent `.igeldb.lock` file is used in each directory. The file itself is deliberately not deleted on release: deleting it after another process has acquired the released inode could allow a third process to lock a new inode.
(release-all! locks)Release directory locks in reverse acquisition order. Idempotent.
Release directory locks in reverse acquisition order. Idempotent.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |