(merge-results higher-precedence lower-precedence)Merge two ordered scan result sequences. Values from higher-precedence
replace values with the same user key in lower-precedence.
Merge two ordered scan result sequences. Values from `higher-precedence` replace values with the same user key in `lower-precedence`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |