Interface for mutations to the data store
Interface for mutations to the data store
(delete! this k)(write! this k v)(write-batch! this entries)(write-data! this k data)Interface for reading from the data store, at a given snapshot-seq (the
newest version of each user_key with seq <= snapshot-seq). Non-tx reads pass
Long/MAX_VALUE (latest).
Interface for reading from the data store, at a given `snapshot-seq` (the newest version of each user_key with seq <= snapshot-seq). Non-tx reads pass `Long/MAX_VALUE` (latest).
(latest-seq this k)(scan this from-key to-key snapshot-seq)(select this k snapshot-seq)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |