(entry-size ikey data)Byte size an entry contributes to the memtable heuristic: the user_key plus, for a live value, the value bytes (seq is not counted).
Byte size an entry contributes to the memtable heuristic: the user_key plus, for a live value, the value bytes (seq is not counted).
(load-existing-wal config)Return [wal-id entries] for crash recovery.
Crash-recovery invariant: every WAL other than the highest-ID one has already been committed to the manifest (a flush appends+fsyncs its manifest edit -- the commit point -- before deleting the WAL). So multiple WALs remaining is the normal result of crashing after a flush's manifest commit but before the WAL delete -- it must not be treated as an error. We replay only the highest-ID WAL and discard the stale ones.
When no WAL exists, the WAL ID starts at 0 with no entries.
Return `[wal-id entries]` for crash recovery. Crash-recovery invariant: every WAL other than the highest-ID one has already been committed to the manifest (a flush appends+fsyncs its manifest edit -- the commit point -- before deleting the WAL). So multiple WALs remaining is the *normal* result of crashing after a flush's manifest commit but before the WAL delete -- it must not be treated as an error. We replay only the highest-ID WAL and discard the stale ones. When no WAL exists, the WAL ID starts at 0 with no entries.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |